@@ -1,4 +1,5 @@
 package Net::Async::Webservice::UPS;
+$Net::Async::Webservice::UPS::VERSION = '1.1.4';
 {
   $Net::Async::Webservice::UPS::DIST = 'Net-Async-Webservice-UPS';
 }
@@ -186,11 +187,10 @@ around BUILDARGS => sub {
 
 sub transaction_reference {
     my ($self,$args) = @_;
-    our $VERSION; # this, and the ||0 later, are to make it work
-                  # before dzil munges it
+    no warnings 'once';
     return {
         CustomerContext => ($args->{customer_context} // "Net::Async::Webservice::UPS"),
-        XpciVersion     => "".($VERSION||0),
+        XpciVersion     => "".($Net::Async::Webservice::UPS::VERSION||0),
     };
 }
 
@@ -738,7 +738,7 @@ Net::Async::Webservice::UPS - UPS API client, non-blocking
 
 =head1 VERSION
 
-version 1.1.3
+version 1.1.4
 
 =head1 SYNOPSIS
 
